<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt" sourcelanguage="en">
<context>
    <name>AboutBox</name>
    <message>
        <source>About FMIT...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FMIT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;version&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Credits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Most open-source softwares are infeasible without indirect contributions provided through libraries. Thus, big thanks to the following geeks:&lt;br /&gt;&lt;br /&gt;- dsboger for so many little and usefull changes, updates, packaging, etc.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars for the tunning scales&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigForm</name>
    <message>
        <source>Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raise the window to the whole screen when the program is started
(You can also use the shortcut &apos;f&apos;).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start in full-screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-save configuration and layout on exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The used tuning scale to determine note frequency values. Useful for tuning historic intruments.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuning scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Werckmeister III</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kirnberger III</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Diatonic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meantone (1/4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Anglo-Saxon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The capture system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected the capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto detect a working capture system at FMIT startup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-detect an available capture system at startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto detect now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name of this FMIT instance in the JACK connections.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fmit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically connect FMIT to the following source at startup (e.g. alsa_pcm:capture_1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>automaticaly connect to...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling rate of the JACK server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JACK sampling rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALSA</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name of the ALSA device to use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <source>The chosen sampling rate.
Do not use a too big sampling rate. 22050Hz should be enough in most cases.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set the sampling rate to the maximum possible value.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>set to max</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mix channels if there are multiple (if unchecked, the first channel will be used)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OSS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name of the OSS device to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/dev/dsp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PortAudio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name of the PortAudio device to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Analysis</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time between each sound analysis.
Can be increased to get less CPU usage (but less temporal precision).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notes range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter the sound below the lowest semitone and above the highest semitone to avoid artefacts and noises in all the following steps of the sound analysis.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notes range filtering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular filter: bad precision, but very fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FIR filter: good precision, but more costly in CPU usage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithm settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore all sounds with volume below this threshold [dB]
(Shown as a red line in various views)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> dB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore weak sub-harmonics.
This threshold is defined between two neighbors frequency components.
Prevents underestimation errors.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use sub-harmonic audibility threshold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Factor defining the window size (from the lowest possible period defined by the notes range).
The bigger this factor, the more stable the analysis. However, by increasing this factor, FMIT will need more CPU and will react slower to sound changes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window size factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume threshold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency refinement settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency refinement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a refinement method in frequency domain: compute the mean of the quasi-harmonic related spectral peaks (the option allows to chose the number of harmonics to use).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum number of harmonics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a refinement method in time domain: compute the mean of various period lengths (the option allows to chose the number of periods to use).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum number of periods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frequency domain fundamental refinement:
mean of the fundamental relative frequencies of the harmonics.
Choose the number of harmonics to use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quantizer settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quantizer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quantize the analysis results: ignore frequency jumps, fill gaps, ignore short notes.
The smaller the value, the faster the tuner. However, by decreasing the value, the computed frequency will be more unstable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore settings as if you just installed FMIT (requires to restart FMIT).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore &amp;factory settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use these settings and quit the configuration panel (it is required to click on the &quot;Save settings&quot; button to permanently keep these settings for each FMIT start)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>Discard any changes and quit the configuration panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options, right-click every view to show up their properties!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use localized note names. e.g.:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hindustani</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Byzantine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transposition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomInstrumentTunerForm</name>
    <message>
        <source>Restore Factory Settings</source>
        <translation>Restaurar Configurações de Fábrica</translation>
    </message>
    <message>
        <source>This operation is NOT reversible.
Are you sure you want to lose all your current settings ?</source>
        <translation>Esta operação NÃO é reversível.
Você tem certeza que quer perder todas as configurações atuais?</translation>
    </message>
    <message>
        <source>You can now restart FMIT to get back factory settings</source>
        <translation>Você quer reiniciar o FMIT agora para voltar suas configurações padrões</translation>
    </message>
    <message>
        <source>The base tunning frequency (the %1 frequency)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allows to add an offset to the reference %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Range of possible notes from the lowest to the highest around the %1 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lowest semitone from the %1 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highest semitone from the %1 reference note.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transposition in number of semitones relative to %1.
Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialView</name>
    <message>
        <source>Dial</source>
        <translation>Dial</translation>
    </message>
    <message>
        <source>Show tolerance</source>
        <translation>Mostrar a tolerância</translation>
    </message>
    <message>
        <source>Show trace</source>
        <translation>Mostrar o traço</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation>Usar centésimais</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation>Faixa da escala</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation>Faixa da escala (em centésimais)</translation>
    </message>
</context>
<context>
    <name>GLErrorHistory</name>
    <message>
        <source>Error history</source>
        <translation>Histórico de erros</translation>
    </message>
    <message>
        <source>Keep previous notes</source>
        <translation>Manter a notas anteriores</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation>Usar Centésimais</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation>Faixa da escala</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation>Faixa da escala (em centésimais)</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>GLFT</name>
    <message>
        <source>Fourier Transform</source>
        <translation>Transformada Fourier</translation>
    </message>
    <message>
        <source>dB scale</source>
        <translation>Escala dB</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>window length</source>
        <translation>Comprimento da janela</translation>
    </message>
    <message>
        <source>- Press left mouse button to move the view</source>
        <translation>Pressione o botão esquerdo do mouse para mover a visualização</translation>
    </message>
    <message>
        <source>- Press SHIFT key and left mouse button to zoom in and out</source>
        <translation>Pressione o botão SHIFT mais o botão esquerdo do mouse para aumentar ou diminuir o zoom</translation>
    </message>
    <message>
        <source>- Double-click to reset the view</source>
        <translation>Dois clicks para resetar a visualização</translation>
    </message>
    <message>
        <source>Frequency %1 [Hz]</source>
        <translation>Frequência %1 [Hz]</translation>
    </message>
</context>
<context>
    <name>GLFreqStruct</name>
    <message>
        <source>Harmonics</source>
        <translation>Harmonicas</translation>
    </message>
    <message>
        <source>Number of harmonics</source>
        <translation>Número de harmonicas</translation>
    </message>
    <message>
        <source>Harmonics&apos; amplitude</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GLGraph</name>
    <message>
        <source>Captured Sound</source>
        <translation>Som capturado</translation>
    </message>
    <message>
        <source>Show Wave Form</source>
        <translation>Mostrar a forma de onda</translation>
    </message>
    <message>
        <source>Auto scale</source>
        <translation>Auto escala</translation>
    </message>
    <message>
        <source>Scale factor</source>
        <translation>Fator da escala</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Max height</source>
        <translation>Nível maximo</translation>
    </message>
</context>
<context>
    <name>GLSample</name>
    <message>
        <source>Show fading</source>
        <translation>Mostrar o decaimento</translation>
    </message>
    <message>
        <source>Number of fading</source>
        <translation>Número de decaimento</translation>
    </message>
    <message>
        <source>Waveform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waveform&apos;s period</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GLStatistics</name>
    <message>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <source>Reset statistics</source>
        <translation>Resetar estatísticas</translation>
    </message>
    <message>
        <source>Keep notes when hidden</source>
        <translation>Mater as notas quando esconder</translation>
    </message>
    <message>
        <source>Keep n values</source>
        <translation>Manter os valores n</translation>
    </message>
    <message>
        <source>Keep this number of values in the computation of the statistics</source>
        <translation>Mater este número de valores nos calculos das estatísticas</translation>
    </message>
    <message>
        <source>Show standard deviation</source>
        <translation>Mostrar o desvio padrão</translation>
    </message>
    <message>
        <source>Scale auto</source>
        <translation>Auto escala</translation>
    </message>
    <message>
        <source>Scale min</source>
        <translation>Escala mínima</translation>
    </message>
    <message>
        <source>Scale min value (in semi-tones)</source>
        <translation>Valor da escala mínima(em semi-tons)</translation>
    </message>
    <message>
        <source>Scale max</source>
        <translation>Escala máxima</translation>
    </message>
    <message>
        <source>Scale max value (in semi-tones)</source>
        <translation>Valores máximos da escala (em semi-tons)</translation>
    </message>
    <message>
        <source>Show tolerance</source>
        <translation>Mostra a tolerância</translation>
    </message>
    <message>
        <source>Use cents</source>
        <translation>Usar centesimais</translation>
    </message>
    <message>
        <source>Scale range</source>
        <translation>Faixa da escala</translation>
    </message>
    <message>
        <source>Scale range (in cents)</source>
        <translation>Faixa da escala (em centesimais)</translation>
    </message>
</context>
<context>
    <name>GLVolumeHistory</name>
    <message>
        <source>Volume history</source>
        <translation>Histórico do volume</translation>
    </message>
    <message>
        <source>Keep previous notes</source>
        <translation>Manter as notas anteriores</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
</context>
<context>
    <name>InstrumentTunerForm</name>
    <message>
        <source>Free Music Instrument Tuner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep the data in the error and volume views (shortcut &quot;k&quot;).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>K
e
e
p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Volume in dB.
Computed in the frequency domain, from the maximum bin.
The maximum is reached when the signal energy is maximal NOT when the sound is saturated in the time domain.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>According to the following colors:
red       : the capture system is not working.
grey     : the capture system is OK, but there is not enough sound.
orange : the analysis conditions are bad (like saturation)
green   : a note is beeing analyzed and analysis conditions are OK.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note Stability</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The base tunning frequency (the A4 frequency)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tuning Frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset in cents from the base tuning frequency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> cents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The frequency of the current note in Hertz.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recognized note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The target frequency of the current note in Hertz.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pause: the capture, the sound analysis and all views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save configuration panel settings, views settings and the window size.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invoke the about box.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MicrotonalView</name>
    <message>
        <source>Unkown filename: &apos;</source>
        <translation>Nome do arquivo desconhecido &apos;</translation>
    </message>
    <message>
        <source>Microtonal</source>
        <translation>Microtons</translation>
    </message>
    <message>
        <source>Used scale</source>
        <translation>Escala usada</translation>
    </message>
    <message>
        <source>Root&apos;s octave</source>
        <translation>Origem&apos;s oitava</translation>
    </message>
    <message>
        <source>Keep root to left side</source>
        <translation>Manter a origem à esquerda</translation>
    </message>
    <message>
        <source>Load Scala file ...</source>
        <translation>Carregar o arquivo de escala ...</translation>
    </message>
    <message>
        <source>Open scale file</source>
        <translation>Abrir o arquivo de escala</translation>
    </message>
    <message>
        <source>Scale name already exist</source>
        <translation>O nome de escala já existe</translation>
    </message>
    <message>
        <source>Invalid file content !</source>
        <translation>Conteúdo inválido</translation>
    </message>
    <message>
        <source>&lt;b&gt;name:&lt;/b&gt; </source>
        <translation>&lt;b&gt;nome:&lt;/b&gt; </translation>
    </message>
    <message>
        <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
        <translation>&lt;b&gt;valor da razão:&lt;/b&gt; </translation>
    </message>
    <message>
        <source>Invalid Scala file: </source>
        <translation>Arquivo de escala inválido: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>default</source>
        <translation type="unfinished">default</translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
